/* read.c */
int read_float(const char *s, float *f);
int read_double(const char *s, double *d);
int read_int(const char *s, int *i);
int read_uint(const char *s, unsigned int *u);
int read_long(const char *s, long int *l);
int read_ulong(const char *s, unsigned long *l);
